@@ -46,4 +46,4 @@ def getChList(xmlpath):
         chlist.append([bctype,ontv,chtxt,chd,csch])
     return chlist
 if __name__ == "__main__":
-    new_chdata(1,1)
\ No newline at end of file
+    new_chdata_all()
\ No newline at end of file
