@@ -3,6 +3,7 @@
 # Rec10 TS Recording Tools
 # Copyright (C) 2009-2010 Yukikaze
 import os
+import os.path
 import time
 import recdblist
 def checkB25Decode(b25filepath, decodedfilepath):
@@ -27,6 +28,8 @@ def compareFilesize(pathbase, path, percentage):
     return true if size of path is larger than that of pathbase.
     percentage is int(0< <100)
     """
+    if not os.path.exists(pathbase):
+        return 0
     basesize = os.path.getsize(pathbase)
     pathsize = os.path.getsize(path)
     size = pathsize * 100-basesize * percentage
