@@ -42,6 +42,12 @@ class DB_MySQL:
             deltatime VARCHAR(5),\
             deltaday VARCHAR(5),\
             opt VARCHAR(20),\
+            epgtitle VARCHAR(100),\
+            epgbtime DATETIME,\
+            epgetime DATETIME,\
+            epgduplicate TINYINT DEFAULT 0,\
+            epgchange TINYINT DEFAULT 0\
+            counter TINYINT DEFAULT -1\
             UNIQUE uni (type,chtxt,title,btime,deltaday)\
             )')
         except:
@@ -328,7 +334,7 @@ class DB_MySQL:
             auto_opt VARCHAR(20),\
             auto_del_tmp TINYINT\
             )')
-            db[1].execute("INSERT IGNORE into in_settings VALUE (0,0,\"G\",1)")
+            db[1].execute("INSERT IGNORE into in_settings VALUE (0,0,\"H\",1)")
         except:
             ""
         self.close_db(db)
@@ -406,13 +412,40 @@ class DB_MySQL:
                 ret=retdb[0][0]
         self.close_db(db)
         return ret
-    def add_timeline(self, type="", chtxt="", title="", btime="", etime="", deltatime="", deltaday="", opt=""):
+    def add_timeline(self, type="", chtxt="", title="", btime="", etime="", deltatime="", deltaday="", opt="" ,counter=-1):
         db = self.connect_db()
         db[1].execute('\
         INSERT IGNORE into timeline \
-        (type,chtxt,title,btime,etime,deltatime,deltaday,opt) \
-        values (%s,%s,%s,%s,%s,%s,%s,%s)', \
-                      (type, chtxt, title, btime, etime, deltatime, deltaday, opt))
+        (type,chtxt,title,btime,etime,deltatime,deltaday,opt,counter) \
+        values (%s,%s,%s,%s,%s,%s,%s,%s,%s)', \
+                      (type, chtxt, title, btime, etime, deltatime, deltaday, opt ,counter))
+        ##db.commit()
+        self.close_db(db)
+    def update_epg_timeline(self,type,chtxt,title,btime,epgbtime,epgetime,epgtitle):
+        db = self.connect_db()
+        db[1].execute('\
+        UPDATE timeline \
+        SET epgbtime=%s,epgetime=%s,epgtitle=%s \
+        WHERE type=%s AND chtxt=%s AND title=%s AND btime=%s ', \
+                      (epgbtime,epgetime,epgtitle,type, chtxt, title, btime))
+        ##db.commit()
+        self.close_db(db)
+    def update_status_change_timeline(self,type,chtxt,title,btime,epgchange):
+        db = self.connect_db()
+        db[1].execute('\
+        UPDATE timeline \
+        SET epgchange =%s \
+        WHERE type=%s AND chtxt=%s AND title=%s AND btime=%s ', \
+                      (epgchange , type, chtxt, title, btime))
+        ##db.commit()
+        self.close_db(db)
+    def update_status_dup_timeline(self,type,chtxt,title,btime,epgduplicate):
+        db = self.connect_db()
+        db[1].execute('\
+        UPDATE timeline \
+        SET epgduplicate =%s \
+        WHERE type=%s AND chtxt=%s AND title=%s AND btime=%s ', \
+                      (epgduplicate , type, chtxt, title, btime))
         ##db.commit()
         self.close_db(db)
     def del_timeline(self, type="", title="", chtxt="", btime=""):
@@ -430,41 +463,19 @@ class DB_MySQL:
         db = self.connect_db()
         recdata = []
         dbr = db[1].execute("\
-        SELECT type, chtxt, title, btime, etime, deltatime ,deltaday ,opt \
+        SELECT type, chtxt, title, btime, etime, deltatime ,deltaday ,opt ,epgbtime ,epgetime ,epgtitle ,epgduplicate ,epgchange ,counter\
         FROM timeline")
         dbl = db[1].fetchall()
         self.close_db(db)
         if dbr > 0:
-            for typet, chtxt, title, btime, etime, deltatime, deltaday, opt in dbl:
-                ret = {}
-                ret['type'] = typet
-                ret['chtxt'] = chtxt
-                ret['title'] = title
-                btime = btime.strftime("%Y-%m-%d %H:%M:%S")
-                etime = etime.strftime("%Y-%m-%d %H:%M:%S")
-                ret['btime'] = btime
-                ret['etime'] = etime
-                ret['opt'] = opt
-                ret['deltatime'] = ""
-                ret['deltaday'] = ""
-                if deltatime == None:
-                    deltatime = "3"
-                if deltaday == None:
-                    deltaday = "7"
-                if typet == 'key':
-                    ret['deltatime'] = deltatime
-                elif typet == 'keyevery':
-                    ret['deltatime'] = deltatime
-                    ret['deltaday'] = deltaday
-                recdata.append(ret)
-        self.close_db(db)
+            recdata = self.getdic_timeline(dbl)
         return recdata
     def select_bytime_timeline(self, dminutes):
         db = self.connect_db()
         recdatum = []
         #dbr=db[1].execute("SELECT type, chtxt, title, btime, etime, deltatime ,deltaday ,opt FROM rectime WHERE btime < DATE_SUB(now(),INTERVAL "+dminutes+" MINUTE ) AND btime > DATE_ADD(now(),INTERVAL "+dminutes+" MINUTE )")
         dbr = db[1].execute("SELECT \
-        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt \
+        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt ,epgbtime ,epgetime ,epgtitle ,epgduplicate ,epgchange ,counter\
         FROM timeline \
         WHERE btime BETWEEN DATE_SUB(now(),INTERVAL " + dminutes + " MINUTE ) AND \
         DATE_ADD(now(),INTERVAL " + dminutes + " MINUTE )")
@@ -472,33 +483,14 @@ class DB_MySQL:
         self.close_db(db)
         #recdblist.printutf8(dbl)
         if dbr > 0:
-            for typet, chtxt, title, btime, etime, deltatime, deltaday, opt in dbl:
-                ret = {}
-                ret['type'] = typet
-                ret['chtxt'] = chtxt
-                ret['title'] = title
-                btime = btime.strftime("%Y-%m-%d %H:%M:%S")
-                etime = etime.strftime("%Y-%m-%d %H:%M:%S")
-                ret['btime'] = btime
-                ret['etime'] = etime
-                ret['opt'] = opt
-                if deltatime == None or deltatime == "":
-                    deltatime = "3"
-                if deltaday == None or deltaday == "":
-                    deltaday = "7"
-                if typet == recdblist.REC_KEYWORD:
-                    ret['deltatime'] = deltatime
-                elif typet == recdblist.REC_KEYWORD_EVERY_SOME_DAYS:
-                    ret['deltatime'] = deltatime
-                    ret['deltaday'] = deltaday
-                recdatum.append(ret)
+            recdatum = self.getdic_timeline(dbl)
         return recdatum
     def select_by_name_time_timeline(self,title,btime,btime2):
         db = self.connect_db()
         recdatum = []
         #dbr=db[1].execute("SELECT type, chtxt, title, btime, etime, deltatime ,deltaday ,opt FROM rectime WHERE btime < DATE_SUB(now(),INTERVAL "+dminutes+" MINUTE ) AND btime > DATE_ADD(now(),INTERVAL "+dminutes+" MINUTE )")
         dbr = db[1].execute("SELECT \
-        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt \
+        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt ,epgbtime ,epgetime ,epgtitle ,epgduplicate ,epgchange ,counter\
         FROM timeline \
         WHERE btime > %s AND \
         btime < %s AND title = %s",(btime,btime2,title))
@@ -506,33 +498,14 @@ class DB_MySQL:
         self.close_db(db)
         #recdblist.printutf8(dbl)
         if dbr > 0:
-            for typet, chtxt, title, btime, etime, deltatime, deltaday, opt in dbl:
-                ret = {}
-                ret['type'] = typet
-                ret['chtxt'] = chtxt
-                ret['title'] = title
-                btime = btime.strftime("%Y-%m-%d %H:%M:%S")
-                etime = etime.strftime("%Y-%m-%d %H:%M:%S")
-                ret['btime'] = btime
-                ret['etime'] = etime
-                ret['opt'] = opt
-                if deltatime == None or deltatime == "":
-                    deltatime = "3"
-                if deltaday == None or deltaday == "":
-                    deltaday = "7"
-                if typet == recdblist.REC_KEYWORD:
-                    ret['deltatime'] = deltatime
-                elif typet == recdblist.REC_KEYWORD_EVERY_SOME_DAYS:
-                    ret['deltatime'] = deltatime
-                    ret['deltaday'] = deltaday
-                recdatum.append(ret)
+            recdatum = self.getdic_timeline(dbl)
         return recdatum
     def select_bytime_all_timeline(self,btime,etime):
         db = self.connect_db()
         recdatum = []
         #dbr=db[1].execute("SELECT type, chtxt, title, btime, etime, deltatime ,deltaday ,opt FROM rectime WHERE btime < DATE_SUB(now(),INTERVAL "+dminutes+" MINUTE ) AND btime > DATE_ADD(now(),INTERVAL "+dminutes+" MINUTE )")
         dbr = db[1].execute("SELECT \
-        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt \
+        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt ,epgbtime ,epgetime ,epgtitle ,epgduplicate ,epgchange ,counter\
         FROM timeline \
         WHERE btime > %s AND \
         etime < %s",(btime,etime))
@@ -540,26 +513,37 @@ class DB_MySQL:
         self.close_db(db)
         #recdblist.printutf8(dbl)
         if dbr > 0:
-            for typet, chtxt, title, btime, etime, deltatime, deltaday, opt in dbl:
-                ret = {}
-                ret['type'] = typet
-                ret['chtxt'] = chtxt
-                ret['title'] = title
-                btime = btime.strftime("%Y-%m-%d %H:%M:%S")
-                etime = etime.strftime("%Y-%m-%d %H:%M:%S")
-                ret['btime'] = btime
-                ret['etime'] = etime
-                ret['opt'] = opt
-                if deltatime == None or deltatime == "":
-                    deltatime = "3"
-                if deltaday == None or deltaday == "":
-                    deltaday = "7"
-                if typet == recdblist.REC_KEYWORD:
-                    ret['deltatime'] = deltatime
-                elif typet == recdblist.REC_KEYWORD_EVERY_SOME_DAYS:
-                    ret['deltatime'] = deltatime
-                    ret['deltaday'] = deltaday
-                recdatum.append(ret)
+            recdatum = self.getdic_timeline(dbl)
+        return recdatum
+    def select_byepgtime_all_timeline(self,epgbtime,epgetime):
+        db = self.connect_db()
+        recdatum = []
+        #dbr=db[1].execute("SELECT type, chtxt, title, btime, etime, deltatime ,deltaday ,opt FROM rectime WHERE btime < DATE_SUB(now(),INTERVAL "+dminutes+" MINUTE ) AND btime > DATE_ADD(now(),INTERVAL "+dminutes+" MINUTE )")
+        dbr = db[1].execute("SELECT \
+        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt ,epgbtime ,epgetime ,epgtitle ,epgduplicate ,epgchange ,counter\
+        FROM timeline \
+        WHERE epgbtime >= %s AND \
+        epgetime <= %s",(epgbtime,epgetime))
+        dbl = db[1].fetchall()
+        self.close_db(db)
+        #recdblist.printutf8(dbl)
+        if dbr > 0:
+            recdatum=self.getdic_timeline(dbl)
+        return recdatum
+    def select_byepgtime_over_timeline(self,epgbtime,epgetime):
+        db = self.connect_db()
+        recdatum = []
+        #dbr=db[1].execute("SELECT type, chtxt, title, btime, etime, deltatime ,deltaday ,opt FROM rectime WHERE btime < DATE_SUB(now(),INTERVAL "+dminutes+" MINUTE ) AND btime > DATE_ADD(now(),INTERVAL "+dminutes+" MINUTE )")
+        dbr = db[1].execute("SELECT \
+        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt ,epgbtime ,epgetime ,epgtitle ,epgduplicate ,epgchange ,counter\
+        FROM timeline \
+        WHERE (NOT(( timeline.epgetime <= %s )OR( timeline.epgbtime >= %s )))"\
+        ,(epgbtime,epgetime))
+        dbl = db[1].fetchall()
+        self.close_db(db)
+        #recdblist.printutf8(dbl)
+        if dbr > 0:
+            recdatum=self.getdic_timeline(dbl)
         return recdatum
     def count_schedule_timeline(self, btime, etime):
         """
@@ -583,12 +567,66 @@ class DB_MySQL:
                     Trec = Trec + 1
         self.close_db(db)
         return [Trec, Srec]
+    def search_schedule_timeline(self,btime,etime):
+        """
+        count rectasknum
+        return [(type,bctype,chtxt,title,btime,etime)]
+        """
+        db = self.connect_db()
+        dbexe = "SELECT type,epg_ch.bctype,timeline.chtxt,title,timeline.btime,timeline.etime FROM timeline INNER JOIN epg_ch ON timeline.chtxt=epg_ch.chtxt"
+        dbexe = dbexe + " WHERE ((NOT(( timeline.etime <= %s )OR( timeline.btime >= %s ))) OR ((timeline.btime = %s) AND (timeline.etime = %s) ) )"
+        ret=[]
+        db[1].execute(dbexe, (btime, etime,btime,etime))
+        dbl=db[1].fetchall()
+        for typet, bctypet, chtxtt, titlet , btimet, etimet in dbl:
+            if (typet == recdblist.REC_RESERVE) or (typet == recdblist.REC_FINAL_RESERVE) or (typet == recdblist.REC_KEYWORD) or (typet == recdblist.REC_KEYWORD_EVERY_SOME_DAYS):
+                ret.append([typet,bctypet,chtxtt,titlet,btimet,etimet])
+        self.close_db(db)
+        return ret
+    def count_epgschedule_timeline(self, epgbtime, epgetime):
+        """
+        count rectasknum
+        return [te num,bs/cs num]
+        """
+        db = self.connect_db()
+        dbexe = "SELECT type,epg_ch.bctype,timeline.chtxt,title FROM timeline INNER JOIN epg_ch ON timeline.chtxt=epg_ch.chtxt"
+        dbexe = dbexe + " WHERE (NOT(( timeline.epgetime <= %s )OR( timeline.epgbtime >= %s )))"
+        Srec = 0
+        Trec = 0
+        db[1].execute(dbexe, (epgbtime, epgetime))
+        dbl=db[1].fetchall()
+        for typet, bctypet, chtxtt, titlet in dbl:
+            if (typet == recdblist.REC_RESERVE) or (typet == recdblist.REC_FINAL_RESERVE) or (typet == recdblist.REC_KEYWORD) or (typet == recdblist.REC_KEYWORD_EVERY_SOME_DAYS):
+                if bctypet.find("cs") > -1:
+                    Srec = Srec + 1
+                elif bctypet.find("bs") > -1:
+                    Srec = Srec + 1
+                elif bctypet.find("te") > -1:
+                    Trec = Trec + 1
+        self.close_db(db)
+        return [Trec, Srec]
+    def search_epgschedule_timeline(self,epgbtime,epgetime):
+        """
+        count rectasknum
+        return [(type,bctype,chtxt,title,btime,etime)]
+        """
+        db = self.connect_db()
+        dbexe = "SELECT type,epg_ch.bctype,timeline.chtxt,title,timeline.btime,timeline.etime FROM timeline INNER JOIN epg_ch ON timeline.chtxt=epg_ch.chtxt"
+        dbexe = dbexe + " WHERE ((NOT(( timeline.epgetime <= %s )OR( timeline.epgbtime >= %s ))) OR ((timeline.epgbtime = %s) AND (timeline.epgetime = %s) ) )"
+        ret=[]
+        db[1].execute(dbexe, (epgbtime, epgetime,epgbtime,epgetime))
+        dbl=db[1].fetchall()
+        for typet, bctypet, chtxtt, titlet , btimet, etimet in dbl:
+            if (typet == recdblist.REC_RESERVE) or (typet == recdblist.REC_FINAL_RESERVE) or (typet == recdblist.REC_KEYWORD) or (typet == recdblist.REC_KEYWORD_EVERY_SOME_DAYS):
+                ret.append([typet,bctypet,chtxtt,titlet,btimet,etimet])
+        self.close_db(db)
+        return ret
     def select_bytime_bychtxt_all_timeline(self,btime,etime,chtxt):
         db = self.connect_db()
         recdatum = []
         #dbr=db[1].execute("SELECT type, chtxt, title, btime, etime, deltatime ,deltaday ,opt FROM rectime WHERE btime < DATE_SUB(now(),INTERVAL "+dminutes+" MINUTE ) AND btime > DATE_ADD(now(),INTERVAL "+dminutes+" MINUTE )")
         dbr = db[1].execute("SELECT \
-        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt \
+        type, chtxt, title, btime, etime, deltatime ,deltaday ,opt ,epgbtime ,epgetime ,epgtitle ,epgduplicate ,epgchange ,counter\
         FROM timeline \
         WHERE btime > %s AND \
         etime < %s\
@@ -597,26 +635,43 @@ class DB_MySQL:
         self.close_db(db)
         #recdblist.printutf8(dbl)
         if dbr > 0:
-            for typet, chtxt, title, btime, etime, deltatime, deltaday, opt in dbl:
-                ret = {}
-                ret['type'] = typet
-                ret['chtxt'] = chtxt
-                ret['title'] = title
-                btime = btime.strftime("%Y-%m-%d %H:%M:%S")
-                etime = etime.strftime("%Y-%m-%d %H:%M:%S")
-                ret['btime'] = btime
-                ret['etime'] = etime
-                ret['opt'] = opt
-                if deltatime == None or deltatime == "":
-                    deltatime = "3"
-                if deltaday == None or deltaday == "":
-                    deltaday = "7"
-                if typet == recdblist.REC_KEYWORD:
-                    ret['deltatime'] = deltatime
-                elif typet == recdblist.REC_KEYWORD_EVERY_SOME_DAYS:
-                    ret['deltatime'] = deltatime
-                    ret['deltaday'] = deltaday
-                recdatum.append(ret)
+            recdatum = self.getdic_timeline(dbl)
+        return recdatum
+    def getdic_timeline(self,timelinelists):
+        recdatum=[]
+        for typet, chtxt, title, btime, etime, deltatime, deltaday, opt ,epgbtimet , epgetimet ,epgtitlet ,epgduplicatet ,epgchanget ,countert in timelinelists:
+            ret = {}
+            ret['type'] = typet
+            ret['chtxt'] = chtxt
+            ret['title'] = title
+            btime = btime.strftime("%Y-%m-%d %H:%M:%S")
+            etime = etime.strftime("%Y-%m-%d %H:%M:%S")
+            ret['btime'] = btime
+            ret['etime'] = etime
+            ret['opt'] = opt
+            try:
+                ret['epgbtime'] = epgbtimet.strftime("%Y-%m-%d %H:%M:%S")
+                ret['epgetime'] = epgetimet.strftime("%Y-%m-%d %H:%M:%S")
+            except:
+                ret['epgbtime'] = "2010-01-01 00:00:00"
+                ret['epgetime'] = "2010-01-01 00:00:00"
+            ret['epgtitle'] = epgtitlet
+            ret['epgduplicate'] = epgduplicatet
+            ret['epgchange'] = epgchanget
+            if deltatime == None or deltatime == "":
+                deltatime = "3"
+            if deltaday == None or deltaday == "":
+                deltaday = "7"
+            if typet == recdblist.REC_KEYWORD:
+                ret['deltatime'] = deltatime
+            elif typet == recdblist.REC_KEYWORD_EVERY_SOME_DAYS:
+                ret['deltatime'] = deltatime
+                ret['deltaday'] = deltaday
+            try:
+                ret['counter'] = int(countert)
+            except:
+                ret['counter']=-1
+            recdatum.append(ret)
         return recdatum
     def delete_old_timeline(self, dhour):
         db = self.connect_db()
@@ -676,7 +731,8 @@ class DB_MySQL:
             terec TINYINT DEFAULT 0,\
             bscsrec TINYINT DEFAULT 0,\
             b252ts TINYINT DEFAULT 0,\
-            installed TINYINT DEFAULT 0\
+            installed TINYINT DEFAULT 0,\
+            version TINYINT\
             )")
             db[1].execute("INSERT IGNORE into in_status VALUE (0,0,0,0,0)")
         except:
@@ -701,7 +757,28 @@ class DB_MySQL:
             r[3]=str(r[3])
             ret.append(r)
         return ret
-        
+    def select_version_in_status(self):
+        db = self.connect_db()
+        version=0
+        try:
+            dbexe = db[1].execute("\
+            SELECT version \
+            FROM in_status \
+            ")
+            if dbexe > 0:
+                dls = db[1].fetchall()
+            self.close_db(db)
+            for dl in dls:
+                r = list(dl)
+                version=int(str(r[0]))
+        except:
+            ""
+        return version
+    def change_version_in_status(self,version):
+        db = self.connect_db()
+        db[1].execute("\
+        UPDATE in_status SET version=%s",str(version))
+        self.close_db(db)
     def change_ts2avi_in_status(self,i):
         """
         statuをiだけ増減する
@@ -975,7 +1052,6 @@ class DB_MySQL:
             return dls[0]
         else:
             return dls
-
     def new_auto_timeline_keyword(self):
         db = self.connect_db()
         try:
@@ -1038,3 +1114,25 @@ class DB_MySQL:
         WHERE \
         btime < DATE_SUB(now(),INTERVAL " + dhour + " HOUR )")
         self.close_db(db)
+    def update_db_to93(self):
+        db = self.connect_db()
+        self.drop_in_settings()
+        self.new_in_settings()
+        db[1].execute("\
+        ALTER TABLE timeline ADD epgtitle VARCHAR(100),\
+        ADD epgbtime DATETIME,\
+        ADD epgetime DATETIME,\
+        ADD epgduplicate TINYINT DEFAULT 0,\
+        ADD epgchange TINYINT DEFAULT 0")
+        db[1].execute("\
+        ALTER TABLE in_status ADD version TINYINT")
+        self.close_db(db)
+        self.change_version_in_status("93")
+    def update_db_93to94(self):
+        db = self.connect_db()
+        self.drop_in_settings()
+        self.new_in_settings()
+        db[1].execute("\
+        ALTER TABLE timeline ADD counter TINYINT DEFAULT -1")
+        self.close_db(db)
+        self.change_version_in_status("94")
\ No newline at end of file
