@@ -1,25 +1,24 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009 Yukikaze
-import chdb
+# Copyright (C) 2009-2010 Yukikaze
 import os
-import time
-import epgdb
 import sys
+import time
 
-update=chdb.update()
-print "番組表更新処理"
-print update
-if len(update)>0:
-    print "番組表を更新"
-    print update
-    pid=os.fork()
-    if pid>0:#親プロセスの場合
+import chdb
+import epgdb
+import recdblist
+
+update = chdb.update()
+if len(update) > 0:
+    #recdblist.printutf8(u"番組表を更新")
+    #print update
+    pid = os.fork()
+    if pid > 0:#親プロセスの場合
         ""
     else:#子プロセスの場合　アップデートを行って終了
         for bctype in update:
             time.sleep(1)
-            print bctype
             epgdb.updatebc(bctype)
         sys.exit(0)
\ No newline at end of file
