@@ -1,15 +1,18 @@
 #!/usr/bin/python
 # coding: UTF-8
 # Rec10 TS Recording Tools
-# Copyright (C) 2009 Yukikaze
+# Copyright (C) 2009-2010 Yukikaze
 import os
 
+import warnings
+warnings.filterwarnings('ignore', "the sets module is deprecated")
 import configreader
 import dbMySQL
-import dbSQLite
 import timerec
 path = str(os.path.dirname(os.path.abspath(__file__))) + "/"
 global rec10db
+def main():
+    timerec.task()
 db = configreader.getdbpath("db")
 if db == "MySQL":
     dbn = configreader.getdbpath("mysql_dbname")
@@ -18,8 +21,9 @@ if db == "MySQL":
     dbpwd = configreader.getdbpath("mysql_passwd")
     dbport = int(configreader.getdbpath("mysql_port"))
     rec10db = dbMySQL.DB_MySQL(dbname=dbn, host=dbh, user=dbu, passwd=dbpwd, port=dbport)
-    rec10db.new_status()
+    rec10db.new_in_status()
 else:
     rec10db = dbSQLite.DB_SQLite(path + "ch.db")
 if __name__ == "__main__":
-    timerec.task()
+    main()
+
