@@ -2,11 +2,10 @@
 # coding: UTF-8
 # Rec10 TS Recording Tools
 # Copyright (C) 2009-2010 Yukikaze
-import ConfigParser
+import configreader
 import os
 import rec10d
 path = os.path.dirname(os.path.abspath(__file__)) + "/"
-
 def changeEncoding(i):
     """
     iはint　増減
@@ -37,3 +36,6 @@ def getSettings_auto_del_tmp():
     return int(rec10d.rec10db.select_all_in_settings()[0][2])
 def getSettings_auto_opt():
     return rec10d.rec10db.select_all_in_settings()[0][3]
+
+def getRecordingMax():
+    return [int(configreader.getenv("te_max")),int(configreader.getenv("bscs_max"))]
