@@ -3,10 +3,14 @@
 # Rec10 TS Recording Tools
 # Copyright (C) 2009-2010 Yukikaze
 #import sys
+import epgdb
 import os
+import time
 import tv2avi
 import tv2mkv
 import checker
+import auto_process
+import install
 #import datetime
 #import rec10d
 #import os
@@ -29,7 +33,7 @@ import checker
 #import guess
 #import zenhan
 #import auto_process
-
+import datetime
 __author__ = "yukikaze"
 path = str(os.path.dirname(os.path.abspath(__file__))) + "/"
 recpath = "/home/ftpusr/ftp-tmp/Recording/"
@@ -37,4 +41,6 @@ ftpusr = "/home/ftpusr/ftp-tmp"
 recordedpath = "/home/ftpusr/ftp5/Series-Finish/"
 
 if __name__ == "__main__":
-    ""
\ No newline at end of file
+    bt=datetime.datetime.now()
+    install.update_db_all()
+    print dt.seconds
\ No newline at end of file
