@@ -33,7 +33,7 @@ def task():
     予定によって子プロセスを生成し処理する。
     """
     try:
-        if rec10d.rec10db.select_installed_in_status()==0:
+        if rec10d.rec10db.select_installed_in_status()==0 or rec10d.rec10db.select_version_in_status()<recdblist.version:
             install.install()
     except:
         install.install()
@@ -62,6 +62,8 @@ def task():
         else:
             time.sleep(10)
             auto_process.auto_check(recpath)
+            time.sleep(10)
+            auto_process.kill_dead_encode(recpath)
             sys.exit()
     update = chdb.update()
     if len(update) > 0:
@@ -81,13 +83,22 @@ def task():
                     recdblist.printutf8(u"放送種別:"+bctype + u"||該当チューナー実行中件数:" + str(status.getBSCSRecording()) + u":直近予約件数:" + str(recdb.countRecNow_minutes_BSCS("10")))
                     recnum = int(configreader.getenv("bscs_max")) -recnum
                 if recnum >0 :
-                    print update
+                    recdblist.printutf8(str(update))
                     rec10d.rec10db.update_status_by_bctype_epg_ch(bctype, "0")
                     epgdb.updatebc(bctype)
                     update = chdb.update()
                     i = i + 1
                 if i > 0:
                     break
+            time.sleep(5)
+            auto_process.update_all_timeline_epg()
+            sys.exit()
+    else:
+        pid = os.fork()
+        if pid != 0:
+            ""
+        else:
+            auto_process.update_all_timeline_epg()
             sys.exit()
     for task in tasks:
         typetxt = task["type"]
@@ -136,11 +147,15 @@ def task():
         elif task["type"] == recdblist.REC_KEYWORD_EVERY_SOME_DAYS:#"keyevery,"+chtxt+","+keyword+","+btime+","+deltatime+","+opt+","+deltaday
             deltatime = task['deltatime']
             deltaday = task['deltaday']
+            try:
+                keyeverycounter=task['counter']
+            except:
+                keyeverycounter=-1
             pid = os.fork()
             if pid != 0:#親プロセスの場合
                 ""
             else:#子プロセスの場合　アップデートを行って終了
-                type_keyword_every_day(task["type"],chtxt, title, bt, et, opt, deltatime, deltaday)
+                type_keyword_every_day(task["type"],chtxt, title, bt, et, opt, deltatime, deltaday,keyeverycounter)
                 sys.exit()
         elif task["type"] == recdblist.REC_FINAL_RESERVE:#"rec,"+chtxt+","+title+","+btime+","+etime+","+opt
             pid = os.fork()
@@ -173,10 +188,22 @@ def task():
                 if pid > 0:#親プロセスの場合
                     ""
                 else:
+                    makeMP4=0
+                    try:
+                        if configreader.getenv("make_mp4")==1:
+                            makeMP4=1
+                    except:
+                        ""
+                    if re.search("m", opt):
+                        makeMP4=0
+                    if re.search("4", opt):
+                        makeMP4=1
                     recdb.del_reckey(recdblist.REC_AVI_TO_MKV, title, chtxt, btime)
                     recdb.rec_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime, etime, opt)
-                    #tv2mp4.avi2mp4(os.path.join(recpath,title+".avi"),os.path.join(recpath,title+".mkv"),opt)
-                    tv2mkv.avi2mkv(os.path.join(recpath,title+".avi"),os.path.join(recpath,title+".mkv"),opt)
+                    if makeMP4==1:
+                        tv2mp4.raw2mp4(os.path.join(recpath,title+".264"),os.path.join(recpath,title+".mp4"),opt)
+                    else:
+                        tv2mkv.raw2mkv(os.path.join(recpath,title+".264"),os.path.join(recpath,title+".mkv"),opt)
                     recdb.del_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime)
                     sys.exit()
         elif task["type"] == recdblist.REC_AVI_TO_MP4:
@@ -185,9 +212,23 @@ def task():
                 if pid > 0:#親プロセスの場合
                     ""
                 else:
+                    makeMP4=0
+                    try:
+                        if configreader.getenv("make_mp4")==1:
+                            makeMP4=1
+                    except:
+                        ""
+                    if re.search("m", opt):
+                        makeMP4=0
+                    if re.search("4", opt):
+                        makeMP4=1
                     recdb.del_reckey(recdblist.REC_AVI_TO_MP4, title, chtxt, btime)
                     recdb.rec_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime, etime, opt)
-                    tv2mp4.avi2mp4(os.path.join(recpath,title+".avi"),os.path.join(recpath,title+".mp4"),opt)
+                    if makeMP4==1:
+                        tv2mp4.ts2mp4(pin, pout, opt)
+                        tv2mp4.raw2mp4(os.path.join(recpath,title+".264"),os.path.join(recpath,title+".mp4"),opt)
+                    else:
+                        tv2mkv.raw2mkv(os.path.join(recpath,title+".264"),os.path.join(recpath,title+".mkv"),opt)
                     recdb.del_reckey(recdblist.REC_CHANGING_CANTAINER, title, chtxt, btime)
                     sys.exit()
         elif task["type"] == recdblist.REC_MKV_TO_MP4:
@@ -231,16 +272,16 @@ def search_keyword(key):
                             topt=status.getSettings_auto_opt()
                             recdb.recreserv(titlet,chtxtt, btimet, etimet,topt)
                     except Exception, inst:
-                        print "error occures in search_keyword_auto_jbk"
-                        print str(type(inst))
-                        print str(inst)
+                        recdblist.printutf8("error occures in search_keyword_auto_jbk")
+                        recdblist.printutf8(str(type(inst)))
+                        recdblist.printutf8(str(inst))
                 else:
                     try:
                         recdb.add_auto_keyword(chtxtt, titlet, btimet, etimet)
                     except Exception, inst:
-                        print "error occures in search_keyword"
-                        print str(type(inst))
-                        print str(inst)
+                        recdblist.printutf8("error occures in search_keyword")
+                        recdblist.printutf8(str(type(inst)))
+                        recdblist.printutf8(str(inst))
 def type_reserve(typetxt,chtxt,title,bt,et,opt):
     btime = bt.strftime("%Y-%m-%d %H:%M:%S")
     etime = et.strftime("%Y-%m-%d %H:%M:%S")
@@ -278,9 +319,9 @@ def type_reserve(typetxt,chtxt,title,bt,et,opt):
                     auto_rec.add_key("ALL", titlen,exp+" "+longexp)
                     recdblist.printutf8(u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
                 except Exception, inst:
-                    print "Error happened in Oikake DB"
-                    print str(type(inst))
-                    print str(inst)
+                    recdblist.printutf8("Error happened in Oikake DB")
+                    recdblist.printutf8(str(type(inst)))
+                    recdblist.printutf8(str(inst))
             else:
                 recdblist.printutf8(u"追いかけ機能エラー：番組データが見付かりません。")
         else:
@@ -309,16 +350,16 @@ def type_reserve(typetxt,chtxt,title,bt,et,opt):
                 auto_rec.add_key("ALL", titlen,exp+" "+longexp)
                 recdblist.printutf8(u"追いかけ機能実行中: "+title+" : "+titlen+" "+btimen+" "+etimen)
             except Exception, inst:
-                print "Error happened in Oikake DB"
-                print type(inst)
-                print inst
+                recdblist.printutf8("Error happened in Oikake DB")
+                recdblist.printutf8(str(type(inst)))
+                recdblist.printutf8(str(inst))
     elif dt <= 20 * 60:
         try:
             recdb.del_reckey(typetxtnow, title, chtxt, btime)
             recdb.rec_reckey(typetxtfinal, title, chtxt, btime, etime, opt)
         except Exception, inst:
-            print type(inst)
-            print inst
+            recdblist.printutf8(str(type(inst)))
+            recdblist.printutf8(str(inst))
 def type_final(typetxt,chtxt,title,bt,et,opt):
     btime = bt.strftime("%Y-%m-%d %H:%M:%S")
     etime = et.strftime("%Y-%m-%d %H:%M:%S")
@@ -331,7 +372,6 @@ def type_final(typetxt,chtxt,title,bt,et,opt):
     tnow = datetime.datetime.now()
     dtt = bt-tnow
     dt = dtt.days * 24 * 60 * 60 + dtt.seconds
-    print dt
     if dt < 6 * 60 and dt > 0:
         newtitle=title
         recdb.del_reckey(typetxtnow, title, chtxt, btime)
@@ -411,8 +451,7 @@ def type_keyword(typetxt,chtxt,title,bt,et,opt,deltatime):
             #    recdblist.printutf8(inst)
         else:
             recdblist.printutf8("nothing match")
-
-def type_keyword_every_day(type,chtxt,title,bt,et,opt,deltatime,deltaday):
+def type_keyword_every_day(type,chtxt,title,bt,et,opt,deltatime,deltaday,counter):
     btime = bt.strftime("%Y-%m-%d %H:%M:%S")
     etime = et.strftime("%Y-%m-%d %H:%M:%S")
     tnow = datetime.datetime.now()
@@ -427,15 +466,32 @@ def type_keyword_every_day(type,chtxt,title,bt,et,opt,deltatime,deltaday):
         etxt = et.strftime("%Y-%m-%d %H:%M:%S")
         recdb.everyreserv(title, chtxt, btxt, etxt, deltatime, opt, deltaday)
     elif dt < 120 * 60:
-        recdb.keyreserv(title, chtxt, btime, etime, deltatime, opt)
         recdb.del_reckey(recdblist.REC_KEYWORD_EVERY_SOME_DAYS, title, chtxt, btime)
         bt = bt + dd
         et = et + dd
         btxt = bt.strftime("%Y-%m-%d %H:%M:%S")
         etxt = et.strftime("%Y-%m-%d %H:%M:%S")
-        recdb.everyreserv(title, chtxt, btxt, etxt, deltatime, opt, deltaday)
-
-
+        if counter>0:
+            recdb.everyreserv(title, chtxt, btxt, etxt, deltatime, opt, deltaday,counter-1)
+        elif counter==-1:
+            recdb.everyreserv(title, chtxt, btxt, etxt, deltatime, opt, deltaday,-1)
+        recdata = epgdb.searchtime2(title, btime, deltatime, chtxt)
+        if recdata[1] != "":
+            chtxtt = recdata[0]
+            titlet = recdata[1]
+            btimet = recdata[2]
+            etimet = recdata[3]
+            exp = recdata[4]
+            longexp = recdata[5]
+            category=recdata[6]
+            bt = datetime.datetime.strptime(btimet, "%Y-%m-%d %H:%M:%S")
+            et = datetime.datetime.strptime(etimet, "%Y-%m-%d %H:%M:%S")
+            btimet = bt.strftime("%Y-%m-%d %H:%M:%S")
+            etimet = et.strftime("%Y-%m-%d %H:%M:%S")
+            #try:
+            recdb.keyreserv(titlet, chtxtt, btimet, etimet, deltatime, opt)
+        else:
+            recdb.keyreserv(title, chtxt, btime, etime, deltatime, opt)
 def type_decode_que(typetxt,chtxt,title,bt,et,opt):
     btime = bt.strftime("%Y-%m-%d %H:%M:%S")
     etime = et.strftime("%Y-%m-%d %H:%M:%S")
@@ -465,7 +521,7 @@ def type_decode_que(typetxt,chtxt,title,bt,et,opt):
                 recdb.rec_reckey(typetxtmiss, title, chtxt, btime, etime, opt)
             else:
                 ch=checker.checkB25Decode(recpath + "/" + title + ".ts.b25", recpath + "/" + title + ".ts")
-                print ch
+                #print ch
                 if ch == 1:
                     os.remove(recpath + "/" + title + ".ts.b25")
             bt = datetime.datetime.strptime(btime, "%Y-%m-%d %H:%M:%S")
@@ -531,9 +587,62 @@ def type_encode_que(typetxt,chtxt,title,bt,et,opt):
                     if not os.path.exists(paac2) and not os.path.exists(pmp32):
                         tv2avi.pentaaudio2sep(os.path.join(recpath, title+".ts"))
                 time.sleep(3)
-            pout = recpath + "/" + title + ".mkv"
+            makeMP4=0
+            try:
+                if configreader.getenv("make_mp4")=="1":
+                    makeMP4=1
+            except:
+                ""
+            if re.search("m", opt):
+                makeMP4=0
+            if re.search("4", opt):
+                makeMP4=1
             recdblist.printutf8(pin)
-            tv2mkv.ts2mkv(pin, pout, opt)
+            if not re.search("0", opt):
+                if makeMP4==1:
+                    pout = recpath + "/" + title + ".mp4"
+                    tv2mp4.ts2mp4(pin, pout, opt)
+                else:
+                    pout = recpath + "/" + title + ".mkv"
+                    tv2mkv.ts2mkv(pin, pout, opt)
+                if re.search("8", opt) or re.search("9", opt):
+                    optt=opt
+                    optt=optt.replace("8","MW8")
+                    optt=optt.replace("9","MW9")
+                    poutt = recpath + "/" + "m_"+title + ".mp4"
+                    if re.search("d", opt) or re.search("5", opt):
+                        if os.path.exists(os.path.join(recpath, "m_"+title+".m2v")):
+                            shutil.move(os.path.join(recpath, title+".m2v"),os.path.join(recpath, "m_"+title+".m2v"))
+                        if os.path.exists(os.path.join(recpath, "m_"+title+"_1.aac")):
+                            shutil.move(os.path.join(recpath, title+"_1.aac"),os.path.join(recpath, "m_"+title+"_1.aac"))
+                        if os.path.exists(os.path.join(recpath, "m_"+title+"_1.mp3")):
+                            shutil.move(os.path.join(recpath, title+"_1.mp3"),os.path.join(recpath, "m_"+title+"_1.mp3"))
+                        if os.path.exists(os.path.join(recpath, "m_"+title+"_2.aac")):
+                            shutil.move(os.path.join(recpath, title+"_2.aac"),os.path.join(recpath, "m_"+title+"_2.aac"))
+                        if os.path.exists(os.path.join(recpath, "m_"+title+"_2.mp3")):
+                            shutil.move(os.path.join(recpath, title+"_2.mp3"),os.path.join(recpath, "m_"+title+"_2.mp3"))
+                    shutil.move(os.path.join(recpath, title+".ts"),os.path.join(recpath, "m_"+title+".ts"))
+                    tv2mp4.ts2mp4(os.path.join(recpath, "m_"+title+".ts"), poutt, optt)
+                    shutil.move(os.path.join(recpath, "m_"+title+".ts"),os.path.join(recpath, title+".ts"))
+            else:
+                optt=opt
+                optt=optt.replace("8","MW8")
+                optt=optt.replace("9","MW9")
+                poutt = recpath + "/" + "m_"+title + ".mp4"
+                shutil.move(os.path.join(recpath, title+".ts"),os.path.join(recpath, "m_"+title+".ts"))
+                if re.search("d", opt) or re.search("5", opt):
+                    if os.path.exists(os.path.join(recpath, "m_"+title+".m2v")):
+                        shutil.move(os.path.join(recpath, title+".m2v"),os.path.join(recpath, "m_"+title+".m2v"))
+                    if os.path.exists(os.path.join(recpath, "m_"+title+"_1.aac")):
+                        shutil.move(os.path.join(recpath, title+"_1.aac"),os.path.join(recpath, "m_"+title+"_1.aac"))
+                    if os.path.exists(os.path.join(recpath, "m_"+title+"_1.mp3")):
+                        shutil.move(os.path.join(recpath, title+"_1.mp3"),os.path.join(recpath, "m_"+title+"_1.mp3"))
+                    if os.path.exists(os.path.join(recpath, "m_"+title+"_2.aac")):
+                        shutil.move(os.path.join(recpath, title+"_2.aac"),os.path.join(recpath, "m_"+title+"_2.aac"))
+                    if os.path.exists(os.path.join(recpath, "m_"+title+"_2.mp3")):
+                        shutil.move(os.path.join(recpath, title+"_2.mp3"),os.path.join(recpath, "m_"+title+"_2.mp3"))
+                tv2mp4.ts2mp4(os.path.join(recpath, "m_"+title+".ts"), poutt, optt)
+                shutil.move(os.path.join(recpath, "m_"+title+".ts"),os.path.join(recpath, title+".ts"))
             recdb.del_reckey(typetxting, title, chtxt, btime)
             time.sleep(10)
             if re.search("E", opt):
