@@ -27,5 +27,8 @@ def wav2mp3_lame(pin,pout):
     lame="lame"
     exe=lame+" -b 128 \""+pin+"\" \""+pout+"\""
     txt=u"Cmd : "+exe+"\n"
-    txt=txt+commands.getoutput(exe.encode('utf-8'))
+    try:
+        txt=txt+commands.getoutput(exe.encode('utf-8'))
+    except:
+        ""
     recdblist.addlog(pin, txt, "Wav2aac_Lame log")
\ No newline at end of file
