@@ -73,18 +73,27 @@ def b252ts(pout, chtxt, btime, etime, opt):
         if pentaaudio == 1:
             pentaaudio2sep(aviin)
     except Exception, inst:
-        print "Error happened in b252ts in tv2avi"
-        print str(type(inst))
-        print str(inst)
+        recdblist.printutf8("Error happened in b252ts in tv2avi")
+        recdblist.printutf8(str(type(inst)))
+        recdblist.printutf8(str(inst))
     status.changeB25Decoding(-1)
 def ts2avi(pin, pout, opt):
     status.changeEncoding(1)
     try:
         ts2x264.ts2x264(pin, pout, opt)
     except Exception, inst:
-        print "error occures in tv2avi.py ts2avi"
-        print type(inst)
-        print inst
+        recdblist.printutf8("error occures in tv2avi.py ts2avi")
+        recdblist.printutf8(str(type(inst)))
+        recdblist.printutf8(str(inst))
+    status.changeEncoding(-1)
+def ts2raw(pin, pout, opt):
+    status.changeEncoding(1)
+    try:
+        ts2x264.ts2x264(pin, pout, opt)
+    except Exception, inst:
+        recdblist.printutf8("error occures in tv2avi.py ts2raw")
+        recdblist.printutf8(str(type(inst)))
+        recdblist.printutf8(str(inst))
     status.changeEncoding(-1)
 def dualaudiots2avi(pin, pout):
     bontsdemux = configreader.getpath('bontsdemux')
@@ -218,6 +227,7 @@ def pentaaudio2sep(pin):
         else:
             tv2audio.wav2mp3_lame(ffpout1, ffpout21)
         time.sleep(3)
+    ffpout21=ffpout1.replace(".wav",".aac")
     if os.path.exists(ffoput21):
         if os.path.getsize(ffpout21)>10*1000*1000:
             os.remove(ffpout1)
