@@ -29,9 +29,9 @@ def tv2ts(pout, ch, csch, time):
     try:
         tv2b25ts(pout + ".b25", ch, time)
     except Exception, inst:
-        print "error occures in tv2ts.py tv2ts"
-        print type(inst)
-        print inst
+        recdblist.printutf8("error occures in tv2ts.py tv2ts")
+        recdblist.printutf8(str(type(inst)))
+        recdblist.printutf8(str(inst))
     if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
         status.changeBSCSRecording(-1)
     else:
@@ -85,9 +85,9 @@ def tv2b25ts(pout, ch, time):
         recdblist.printutf8(doexe)
         recdblist.addlog(pout, unicode(commands.getoutput(doexe.encode('utf-8')),'utf-8'), u"recpt1-log")
     except Exception, inst:
-        print "error occures in tv2ts.py tv2b25ts"
-        print type(inst)
-        print inst
+        recdblist.printutf8("error occures in tv2ts.py tv2b25ts")
+        recdblist.printutf8(str(type(inst)))
+        recdblist.printutf8(str(inst))
     if len(ch) > 2:#BS/CSは100とかCS??とかなので3文字以上
         status.changeBSCSRecording(-1)
     else:
